window.Gleam.initSearch([{"doc":"glitr","title":"glitr","content":"# glitr\r\n\r\nGleam typed routes library for type-safe fullstack development\r\n\r\n[![Package Version](https://img.shields.io/hexpm/v/glitr)](https://hex.pm/packages/glitr)\r\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glitr/)\r\n\r\n```sh\r\ngleam add glitr\r\n```\r\n```gleam\r\nimport glitr\r\nimport glitr/utils\r\nimport gleam/json\r\nimport gleam/dynamic\r\nimport gleam/http\r\n\r\npub type Todo {\r\n  Todo(id: String, title: String)\r\n}\r\n\r\nfn encoder(t: Todo) -&gt; json.Json {\r\n  json.object([\r\n    #(&quot;id&quot;, json.string(t.id)),\r\n    #(&quot;title&quot;, json.string(t.title)),\r\n  ])\r\n}\r\n\r\nfn decoder(\r\n  value: dynamic.Dynamic,\r\n) -&gt; Result(Todo, List(dynamic.DecodeError)) {\r\n  value\r\n  |&gt; dynamic.decode2(\r\n    Todo,\r\n    dynamic.field(&quot;id&quot;, dynamic.string),\r\n    dynamic.field(&quot;title&quot;, dynamic.string),\r\n  )\r\n}\r\n\r\npub fn main() {\r\n  let todo_converter = glitr.JsonConverter(encoder, decoder)\r\n  let get_all_todos_route = glitr.Route(\r\n    http.Get,\r\n    http.Http,\r\n    &quot;localhost&quot;,\r\n    2345,\r\n    False,\r\n    utils.simple_path_converter([&quot;todos&quot;]),\r\n    utils.no_body_converter(),\r\n    todo_converter\r\n  )\r\n\r\n  // This route can be shared and used by both frontend and backend applications\r\n\r\n  // Here is an example for a frontend application\r\n  let request = get_all_todos_route |&gt; utils.to_request(Nil, Nil)\r\n\r\n  // Use request as you wish (with glitr_lustre for example)\r\n}\r\n```\r\n\r\nFurther documentation can be found at &lt;https://hexdocs.pm/glitr&gt;.\r\n\r\n## Development\r\n\r\n```sh\r\ngleam run   # Run the project\r\ngleam test  # Run the tests\r\n```\r\n","url":"index.html"},{"doc":"glitr","title":"JsonConverter","content":"pub type JsonConverter(a) {\n  JsonConverter(encoder: JsonEncoder(a), decoder: JsonDecoder(a))\n}\n\nJsonConverter(encoder: JsonEncoder(a), decoder: JsonDecoder(a))\n\n\nSynonyms:\nglitr.JsonConverter\nglitr JsonConverter","url":"glitr.html#JsonConverter"},{"doc":"glitr","title":"JsonDecoder","content":"pub type JsonDecoder(a) =\n  fn(dynamic.Dynamic) -&gt; Result(a, List(dynamic.DecodeError))\n\n\nSynonyms:\nglitr.JsonDecoder\nglitr JsonDecoder","url":"glitr.html#JsonDecoder"},{"doc":"glitr","title":"JsonEncoder","content":"pub type JsonEncoder(a) =\n  fn(a) -&gt; json.Json\n\n\nSynonyms:\nglitr.JsonEncoder\nglitr JsonEncoder","url":"glitr.html#JsonEncoder"},{"doc":"glitr","title":"PathConverter","content":"pub type PathConverter(a) {\n  PathConverter(encoder: PathEncoder(a), decoder: PathDecoder(a))\n}\n\nPathConverter(encoder: PathEncoder(a), decoder: PathDecoder(a))\n\n\nSynonyms:\nglitr.PathConverter\nglitr PathConverter","url":"glitr.html#PathConverter"},{"doc":"glitr","title":"PathDecoder","content":"pub type PathDecoder(a) =\n  fn(List(String)) -&gt; Result(a, Nil)\n\n\nSynonyms:\nglitr.PathDecoder\nglitr PathDecoder","url":"glitr.html#PathDecoder"},{"doc":"glitr","title":"PathEncoder","content":"pub type PathEncoder(a) =\n  fn(a) -&gt; List(String)\n\n\nSynonyms:\nglitr.PathEncoder\nglitr PathEncoder","url":"glitr.html#PathEncoder"},{"doc":"glitr","title":"QueryConverter","content":"pub type QueryConverter(a) {\n  QueryConverter(\n    encoder: QueryEncoder(a),\n    decoder: QueryDecoder(a),\n  )\n}\n\nQueryConverter(\n  encoder: QueryEncoder(a),\n  decoder: QueryDecoder(a),\n)\n\n\nSynonyms:\nglitr.QueryConverter\nglitr QueryConverter","url":"glitr.html#QueryConverter"},{"doc":"glitr","title":"QueryDecoder","content":"pub type QueryDecoder(a) =\n  fn(List(#(String, String))) -&gt; Result(a, Nil)\n\n\nSynonyms:\nglitr.QueryDecoder\nglitr QueryDecoder","url":"glitr.html#QueryDecoder"},{"doc":"glitr","title":"QueryEncoder","content":"pub type QueryEncoder(a) =\n  fn(a) -&gt; List(#(String, String))\n\n\nSynonyms:\nglitr.QueryEncoder\nglitr QueryEncoder","url":"glitr.html#QueryEncoder"},{"doc":"glitr","title":"Route","content":"pub type Route(\n  path_type,\n  query_type,\n  req_body_type,\n  res_body_type,\n) {\n  Route(\n    method: http.Method,\n    path_converter: option.Option(PathConverter(path_type)),\n    query_converter: option.Option(QueryConverter(query_type)),\n    req_body_converter: option.Option(\n      JsonConverter(req_body_type),\n    ),\n    res_body_converter: option.Option(\n      JsonConverter(res_body_type),\n    ),\n  )\n}\n\nRoute(\n  method: http.Method,\n  path_converter: option.Option(PathConverter(path_type)),\n  query_converter: option.Option(QueryConverter(query_type)),\n  req_body_converter: option.Option(JsonConverter(req_body_type)),\n  res_body_converter: option.Option(JsonConverter(res_body_type)),\n)\n\n\nSynonyms:\nglitr.Route\nglitr Route","url":"glitr.html#Route"},{"doc":"glitr","title":"RouteOptions","content":"pub type RouteOptions(p, q, b) {\n  RouteOptions(path: p, query: q, body: b)\n}\n\nRouteOptions(path: p, query: q, body: b)\n\n\nSynonyms:\nglitr.RouteOptions\nglitr RouteOptions","url":"glitr.html#RouteOptions"},{"doc":"glitr","title":"glitr","content":"","url":"glitr.html"},{"doc":"glitr/error","title":"GlitrError","content":"pub type GlitrError {\n  RouteError(msg: String)\n}\n\nRouteError(msg: String)\n\n\nSynonyms:\nglitr/error.GlitrError\nglitr/error GlitrError","url":"glitr/error.html#GlitrError"},{"doc":"glitr/error","title":"glitr/error","content":"","url":"glitr/error.html"},{"doc":"glitr/route","title":"new","content":"pub fn new() -&gt; Route(Nil, Nil, Nil, Nil)\n\nSynonyms:\nglitr/route.new\nglitr/route new","url":"glitr/route.html#new"},{"doc":"glitr/route","title":"with_method","content":"pub fn with_method(\n  route: Route(a, b, c, d),\n  method: Method,\n) -&gt; Route(a, b, c, d)\n\nSynonyms:\nglitr/route.with_method\nglitr/route with_method","url":"glitr/route.html#with_method"},{"doc":"glitr/route","title":"with_path_converter","content":"pub fn with_path_converter(\n  route: Route(a, b, c, d),\n  path_converter: PathConverter(e),\n) -&gt; Route(e, b, c, d)\n\nSynonyms:\nglitr/route.with_path_converter\nglitr/route with_path_converter","url":"glitr/route.html#with_path_converter"},{"doc":"glitr/route","title":"with_query_converter","content":"pub fn with_query_converter(\n  route: Route(a, b, c, d),\n  query_converter: QueryConverter(e),\n) -&gt; Route(a, e, c, d)\n\nSynonyms:\nglitr/route.with_query_converter\nglitr/route with_query_converter","url":"glitr/route.html#with_query_converter"},{"doc":"glitr/route","title":"with_request_body_converter","content":"pub fn with_request_body_converter(\n  route: Route(a, b, c, d),\n  req_body_converter: JsonConverter(e),\n) -&gt; Route(a, b, e, d)\n\nSynonyms:\nglitr/route.with_request_body_converter\nglitr/route with_request_body_converter","url":"glitr/route.html#with_request_body_converter"},{"doc":"glitr/route","title":"with_response_body_converter","content":"pub fn with_response_body_converter(\n  route: Route(a, b, c, d),\n  res_body_converter: JsonConverter(e),\n) -&gt; Route(a, b, c, e)\n\nSynonyms:\nglitr/route.with_response_body_converter\nglitr/route with_response_body_converter","url":"glitr/route.html#with_response_body_converter"},{"doc":"glitr/route","title":"glitr/route","content":"","url":"glitr/route.html"},{"doc":"glitr/utils","title":"id_path_converter","content":"pub fn id_path_converter(\n  root: List(String),\n) -&gt; PathConverter(String)\n\nSynonyms:\nglitr/utils.id_path_converter\nglitr/utils id_path_converter","url":"glitr/utils.html#id_path_converter"},{"doc":"glitr/utils","title":"simple_path_converter","content":"pub fn simple_path_converter(\n  root: List(String),\n) -&gt; PathConverter(Nil)\n\nSynonyms:\nglitr/utils.simple_path_converter\nglitr/utils simple_path_converter","url":"glitr/utils.html#simple_path_converter"},{"doc":"glitr/utils","title":"to_request","content":"pub fn to_request(\n  route: Route(a, b, c, d),\n  path: a,\n  query: b,\n  body: c,\n) -&gt; Request(String)\n\nSynonyms:\nglitr/utils.to_request\nglitr/utils to_request","url":"glitr/utils.html#to_request"},{"doc":"glitr/utils","title":"glitr/utils","content":"","url":"glitr/utils.html"},{"doc":"glitr/service","title":"RouteService","content":"pub type RouteService(base_type, upsert_type) {\n  RouteService(\n    root_path: List(String),\n    base_converter: option.Option(glitr.JsonConverter(base_type)),\n    upsert_converter: option.Option(\n      glitr.JsonConverter(upsert_type),\n    ),\n  )\n}\n\nRouteService(\n  root_path: List(String),\n  base_converter: option.Option(glitr.JsonConverter(base_type)),\n  upsert_converter: option.Option(\n    glitr.JsonConverter(upsert_type),\n  ),\n)\n\n\nSynonyms:\nglitr/service.RouteService\nglitr/service RouteService","url":"glitr/service.html#RouteService"},{"doc":"glitr/service","title":"create_route","content":"pub fn create_route(\n  service: RouteService(a, b),\n) -&gt; Result(Route(Nil, Nil, b, a), GlitrError)\n\nSynonyms:\nglitr/service.create_route\nglitr/service create_route","url":"glitr/service.html#create_route"},{"doc":"glitr/service","title":"delete_route","content":"pub fn delete_route(\n  service: RouteService(a, b),\n) -&gt; Result(Route(String, Nil, Nil, String), GlitrError)\n\nSynonyms:\nglitr/service.delete_route\nglitr/service delete_route","url":"glitr/service.html#delete_route"},{"doc":"glitr/service","title":"get_all_route","content":"pub fn get_all_route(\n  service: RouteService(a, b),\n) -&gt; Result(Route(Nil, Nil, Nil, List(a)), GlitrError)\n\nSynonyms:\nglitr/service.get_all_route\nglitr/service get_all_route","url":"glitr/service.html#get_all_route"},{"doc":"glitr/service","title":"get_route","content":"pub fn get_route(\n  service: RouteService(a, b),\n) -&gt; Result(Route(String, Nil, Nil, a), GlitrError)\n\nSynonyms:\nglitr/service.get_route\nglitr/service get_route","url":"glitr/service.html#get_route"},{"doc":"glitr/service","title":"new","content":"pub fn new() -&gt; RouteService(a, b)\n\nSynonyms:\nglitr/service.new\nglitr/service new","url":"glitr/service.html#new"},{"doc":"glitr/service","title":"update_route","content":"pub fn update_route(\n  service: RouteService(a, b),\n) -&gt; Result(Route(String, Nil, b, a), GlitrError)\n\nSynonyms:\nglitr/service.update_route\nglitr/service update_route","url":"glitr/service.html#update_route"},{"doc":"glitr/service","title":"with_base_converter","content":"pub fn with_base_converter(\n  service: RouteService(a, b),\n  base_converter: JsonConverter(a),\n) -&gt; RouteService(a, b)\n\nSynonyms:\nglitr/service.with_base_converter\nglitr/service with_base_converter","url":"glitr/service.html#with_base_converter"},{"doc":"glitr/service","title":"with_root_path","content":"pub fn with_root_path(\n  service: RouteService(a, b),\n  root_path: List(String),\n) -&gt; RouteService(a, b)\n\nSynonyms:\nglitr/service.with_root_path\nglitr/service with_root_path","url":"glitr/service.html#with_root_path"},{"doc":"glitr/service","title":"with_upsert_converter","content":"pub fn with_upsert_converter(\n  service: RouteService(a, b),\n  upsert_converter: JsonConverter(b),\n) -&gt; RouteService(a, b)\n\nSynonyms:\nglitr/service.with_upsert_converter\nglitr/service with_upsert_converter","url":"glitr/service.html#with_upsert_converter"},{"doc":"glitr/service","title":"glitr/service","content":"","url":"glitr/service.html"}]);